summaryrefslogtreecommitdiffstats
path: root/generic/tclBasic.c
diff options
context:
space:
mode:
authorjan.nijtmans <nijtmans@users.sourceforge.net>2020-09-01 10:51:52 (GMT)
committerjan.nijtmans <nijtmans@users.sourceforge.net>2020-09-01 10:51:52 (GMT)
commita9843e57c2416046ee657b66dc7bd9e4fba46ff3 (patch)
tree2b31c0b522cabcc83bfbdc542d942ed04f6b9377 /generic/tclBasic.c
parent0468c659f572aac50eac5f2fbdd0b7be8948496c (diff)
parentd99566171273e05f659f3f4f364b9d1948ec8565 (diff)
downloadtcl-a9843e57c2416046ee657b66dc7bd9e4fba46ff3.zip
tcl-a9843e57c2416046ee657b66dc7bd9e4fba46ff3.tar.gz
tcl-a9843e57c2416046ee657b66dc7bd9e4fba46ff3.tar.bz2
Merge 8.7
Diffstat (limited to 'generic/tclBasic.c')
-rw-r--r--generic/tclBasic.c72
1 files changed, 36 insertions, 36 deletions
diff --git a/generic/tclBasic.c b/generic/tclBasic.c
index 7337885..9398aff 100644
--- a/generic/tclBasic.c
+++ b/generic/tclBasic.c
@@ -662,7 +662,7 @@ Tcl_CreateInterp(void)
TclRegisterCommandTypeName(TclEnsembleImplementationCmd, "ensemble");
TclRegisterCommandTypeName(TclAliasObjCmd, "alias");
TclRegisterCommandTypeName(TclLocalAliasObjCmd, "alias");
- TclRegisterCommandTypeName(TclSlaveObjCmd, "interp");
+ TclRegisterCommandTypeName(TclChildObjCmd, "interp");
TclRegisterCommandTypeName(TclInvokeImportedCmd, "import");
TclRegisterCommandTypeName(TclOOPublicObjectCmd, "object");
TclRegisterCommandTypeName(TclOOPrivateObjectCmd, "privateObject");
@@ -3713,7 +3713,7 @@ CancelEvalProc(
TclSetCancelFlags(iPtr, cancelInfo->flags | CANCELED);
/*
* Now, we must set the script cancellation flags on all the slave
* interpreters belonging to this one.
*/
@@ -3881,7 +3881,7 @@ TclResetCancellation(
* Tcl_Canceled --
*
* Check if the script in progress has been canceled, i.e.,
- * Tcl_CancelEval was called for this interpreter or any of its master
+ * Tcl_CancelEval was called for this interpreter or any of its parent
* interpreters.
*
* Results:
@@ -4893,7 +4893,7 @@ TclEvalEx(
* the embedded command, which is refered to
* by 'script'. The 'clNextOuter' refers to
* the current entry in the table of
- * continuation lines in this "master script",
+ * continuation lines in this "main script",
* and the character offsets are relative to
* the 'outerScript' as well.
*
@@ -6425,7 +6425,7 @@ TclObjInvoke(
int
TclNRInvoke(
- TCL_UNUSED(ClientData),
+ TCL_UNUSED(void *),
Tcl_Interp *interp,
int objc,
Tcl_Obj *const objv[])
@@ -6755,7 +6755,7 @@ Tcl_GetVersion(
static int
ExprCeilFunc(
- TCL_UNUSED(ClientData),
+ TCL_UNUSED(void *),
Tcl_Interp *interp, /* The interpreter in which to execute the
* function. */
int objc, /* Actual parameter count. */
@@ -6795,7 +6795,7 @@ ExprCeilFunc(
static int
ExprFloorFunc(
- TCL_UNUSED(ClientData),
+ TCL_UNUSED(void *),
Tcl_Interp *interp, /* The interpreter in which to execute the
* function. */
int objc, /* Actual parameter count. */
@@ -6835,7 +6835,7 @@ ExprFloorFunc(
static int
ExprIsqrtFunc(
- TCL_UNUSED(ClientData),
+ TCL_UNUSED(void *),
Tcl_Interp *interp, /* The interpreter in which to execute. */
int objc, /* Actual parameter count. */
Tcl_Obj *const *objv) /* Actual parameter list. */
@@ -6941,7 +6941,7 @@ ExprIsqrtFunc(
static int
ExprSqrtFunc(
- TCL_UNUSED(ClientData),
+ TCL_UNUSED(void *),
Tcl_Interp *interp, /* The interpreter in which to execute the
* function. */
int objc, /* Actual parameter count. */
@@ -7109,7 +7109,7 @@ ExprBinaryFunc(
static int
ExprAbsFunc(
- TCL_UNUSED(ClientData),
+ TCL_UNUSED(void *),
Tcl_Interp *interp, /* The interpreter in which to execute the
* function. */
int objc, /* Actual parameter count. */
@@ -7208,7 +7208,7 @@ ExprAbsFunc(
static int
ExprBoolFunc(
- TCL_UNUSED(ClientData),
+ TCL_UNUSED(void *),
Tcl_Interp *interp, /* The interpreter in which to execute the
* function. */
int objc, /* Actual parameter count. */
@@ -7229,7 +7229,7 @@ ExprBoolFunc(
static int
ExprDoubleFunc(
- TCL_UNUSED(ClientData),
+ TCL_UNUSED(void *),
Tcl_Interp *interp, /* The interpreter in which to execute the
* function. */
int objc, /* Actual parameter count. */
@@ -7256,7 +7256,7 @@ ExprDoubleFunc(
static int
ExprIntFunc(
- TCL_UNUSED(ClientData),
+ TCL_UNUSED(void *),
Tcl_Interp *interp, /* The interpreter in which to execute the
* function. */
int objc, /* Actual parameter count. */
@@ -7312,7 +7312,7 @@ ExprIntFunc(
static int
ExprWideFunc(
- TCL_UNUSED(ClientData),
+ TCL_UNUSED(void *),
Tcl_Interp *interp, /* The interpreter in which to execute the
* function. */
int objc, /* Actual parameter count. */
@@ -7333,7 +7333,7 @@ ExprWideFunc(
*/
static int
ExprMaxMinFunc(
- TCL_UNUSED(ClientData),
+ TCL_UNUSED(void *),
Tcl_Interp *interp, /* The interpreter in which to execute the
* function. */
int objc, /* Actual parameter count. */
@@ -7373,7 +7373,7 @@ ExprMaxMinFunc(
static int
ExprMaxFunc(
- TCL_UNUSED(ClientData),
+ TCL_UNUSED(void *),
Tcl_Interp *interp, /* The interpreter in which to execute the
* function. */
int objc, /* Actual parameter count. */
@@ -7384,7 +7384,7 @@ ExprMaxFunc(
static int
ExprMinFunc(
- TCL_UNUSED(ClientData),
+ TCL_UNUSED(void *),
Tcl_Interp *interp, /* The interpreter in which to execute the
* function. */
int objc, /* Actual parameter count. */
@@ -7395,7 +7395,7 @@ ExprMinFunc(
static int
ExprRandFunc(
- TCL_UNUSED(ClientData),
+ TCL_UNUSED(void *),
Tcl_Interp *interp, /* The interpreter in which to execute the
* function. */
int objc, /* Actual parameter count. */
@@ -7488,7 +7488,7 @@ ExprRandFunc(
static int
ExprRoundFunc(
- TCL_UNUSED(ClientData),
+ TCL_UNUSED(void *),
Tcl_Interp *interp, /* The interpreter in which to execute the
* function. */
int objc, /* Actual parameter count. */
@@ -7567,7 +7567,7 @@ ExprRoundFunc(
static int
ExprSrandFunc(
- TCL_UNUSED(ClientData),
+ TCL_UNUSED(void *),
Tcl_Interp *interp, /* The interpreter in which to execute the
* function. */
int objc, /* Actual parameter count. */
@@ -7756,7 +7756,7 @@ ClassifyDouble(
static int
ExprIsFiniteFunc(
- TCL_UNUSED(ClientData),
+ TCL_UNUSED(void *),
Tcl_Interp *interp, /* The interpreter in which to execute the
* function. */
int objc, /* Actual parameter count */
@@ -7787,7 +7787,7 @@ ExprIsFiniteFunc(
static int
ExprIsInfinityFunc(
- TCL_UNUSED(ClientData),
+ TCL_UNUSED(void *),
Tcl_Interp *interp, /* The interpreter in which to execute the
* function. */
int objc, /* Actual parameter count */
@@ -7817,7 +7817,7 @@ ExprIsInfinityFunc(
static int
ExprIsNaNFunc(
- TCL_UNUSED(ClientData),
+ TCL_UNUSED(void *),
Tcl_Interp *interp, /* The interpreter in which to execute the
* function. */
int objc, /* Actual parameter count */
@@ -7847,7 +7847,7 @@ ExprIsNaNFunc(
static int
ExprIsNormalFunc(
- TCL_UNUSED(ClientData),
+ TCL_UNUSED(void *),
Tcl_Interp *interp, /* The interpreter in which to execute the
* function. */
int objc, /* Actual parameter count */
@@ -7877,7 +7877,7 @@ ExprIsNormalFunc(
static int
ExprIsSubnormalFunc(
- TCL_UNUSED(ClientData),
+ TCL_UNUSED(void *),
Tcl_Interp *interp, /* The interpreter in which to execute the
* function. */
int objc, /* Actual parameter count */
@@ -7907,7 +7907,7 @@ ExprIsSubnormalFunc(
static int
ExprIsUnorderedFunc(
- TCL_UNUSED(ClientData),
+ TCL_UNUSED(void *),
Tcl_Interp *interp, /* The interpreter in which to execute the
* function. */
int objc, /* Actual parameter count */
@@ -7948,7 +7948,7 @@ ExprIsUnorderedFunc(
static int
FloatClassifyObjCmd(
- TCL_UNUSED(ClientData),
+ TCL_UNUSED(void *),
Tcl_Interp *interp, /* The interpreter in which to execute the
* function. */
int objc, /* Actual parameter count */
@@ -8057,7 +8057,7 @@ MathFuncWrongNumArgs(
static int
DTraceObjCmd(
- TCL_UNUSED(ClientData),
+ TCL_UNUSED(void *),
TCL_UNUSED(Tcl_Interp *),
int objc, /* Number of arguments. */
Tcl_Obj *const objv[]) /* Argument objects. */
@@ -8441,7 +8441,7 @@ TclSetTailcall(
int
TclNRTailcallObjCmd(
- TCL_UNUSED(ClientData),
+ TCL_UNUSED(void *),
Tcl_Interp *interp,
int objc,
Tcl_Obj *const objv[])
@@ -8634,7 +8634,7 @@ TclNRYieldObjCmd(
int
TclNRYieldToObjCmd(
- TCL_UNUSED(ClientData),
+ TCL_UNUSED(void *),
Tcl_Interp *interp,
int objc,
Tcl_Obj *const objv[])
@@ -8944,7 +8944,7 @@ TclNREvalList(
static int
CoroTypeObjCmd(
- TCL_UNUSED(ClientData),
+ TCL_UNUSED(void *),
Tcl_Interp *interp,
int objc,
Tcl_Obj *const objv[])
@@ -9034,7 +9034,7 @@ GetCoroutineFromObj(
static int
TclNRCoroInjectObjCmd(
- TCL_UNUSED(ClientData),
+ TCL_UNUSED(void *),
Tcl_Interp *interp,
int objc,
Tcl_Obj *const objv[])
@@ -9079,7 +9079,7 @@ TclNRCoroInjectObjCmd(
static int
TclNRCoroProbeObjCmd(
- TCL_UNUSED(ClientData),
+ TCL_UNUSED(void *),
Tcl_Interp *interp,
int objc,
Tcl_Obj *const objv[])
@@ -9272,7 +9272,7 @@ InjectHandlerPostCall(
static int
NRInjectObjCmd(
- TCL_UNUSED(ClientData),
+ TCL_UNUSED(void *),
Tcl_Interp *interp,
int objc,
Tcl_Obj *const objv[])
@@ -9381,7 +9381,7 @@ TclNRInterpCoroutine(
int
TclNRCoroutineObjCmd(
- TCL_UNUSED(ClientData),
+ TCL_UNUSED(void *),
Tcl_Interp *interp, /* Current interpreter. */
int objc, /* Number of arguments. */
Tcl_Obj *const objv[]) /* Argument objects. */
@@ -9514,7 +9514,7 @@ TclNRCoroutineObjCmd(
int
TclInfoCoroutineCmd(
- TCL_UNUSED(ClientData),
+ TCL_UNUSED(void *),
Tcl_Interp *interp,
int objc,
Tcl_Obj *const objv[])
@@ -3713,7 +3713,7 @@ CancelEvalProc(
TclSetCancelFlags(iPtr, cancelInfo->flags | CANCELED);
/*
- * Now, we must set the script cancellation flags on all the slave
+ * Now, we must set the script cancellation flags on all the child
* interpreters belonging to this one.
*/